summaryrefslogtreecommitdiffstats
path: root/test
diff options
context:
space:
mode:
authorluke <luke@980ebf18-57e1-0310-9a29-db15c13687c0>2006-04-11 22:32:51 +0000
committerluke <luke@980ebf18-57e1-0310-9a29-db15c13687c0>2006-04-11 22:32:51 +0000
commit71793fb3d096b74977b73fffe16bbeb8f45c94b9 (patch)
treeb1d2ac064df3fbe004b216112fea8ab2a0856b15 /test
parentf522a7e4fe87de6214d1d8e5e6d587d1948117ab (diff)
Changing "set" to "tag"
git-svn-id: https://reductivelabs.com/svn/puppet/trunk@1106 980ebf18-57e1-0310-9a29-db15c13687c0
Diffstat (limited to 'test')
-rwxr-xr-xtest/language/ast.rb8
-rw-r--r--test/puppettest.rb6
2 files changed, 7 insertions, 7 deletions
diff --git a/test/puppettest.rb b/test/puppettest.rb
index 470a3d4fe..323da53e6 100644
--- a/test/puppettest.rb
+++ b/test/puppettest.rb
@@ -738,7 +738,7 @@ module ParserTesting
}
end
- def setobj(*names)
+ def tagobj(*names)
args = {}
newnames = names.collect do |name|
if name.is_a? AST
@@ -748,8 +748,8 @@ module ParserTesting
end
end
args[:type] = astarray(*newnames)
- assert_nothing_raised("Could not create class %s" % names.inspect) {
- return AST::Set.new(args)
+ assert_nothing_raised("Could not create tag %s" % names.inspect) {
+ return AST::Tag.new(args)
}
end
diff --git a/test/language/ast.rb b/test/language/ast.rb
index 5ffb72091..d87cf033c 100755
--- a/test/language/ast.rb
+++ b/test/language/ast.rb
@@ -65,9 +65,9 @@ class TestAST < Test::Unit::TestCase
assert_equal(classes.sort, scope.classlist.sort)
end
# Test that 'setobject' collects all of an object's parameters and stores
# them in one TransObject, rather than many. This is probably a bad idea.
- def test_setobject
+ def test_tagobject
top = nil
children = [
fileobj("/etc", "owner" => "root"),
@@ -651,8 +651,8 @@ class TestAST < Test::Unit::TestCase
children = []
# Create child class one
children << varobj("variable", "aclass")
- children << setobj(type, varref("variable"))
- children << setobj(type)
+ children << tagobj(type, varref("variable"))
+ children << tagobj(type)
classes << "aclass"
@@ -65,9 +65,9 @@ class TestAST < Test::Unit::TestCase
assert_equal(classes.sort, scope.classlist.sort)
end
- # Test that 'setobject' collects all of an object's parameters and stores
+ # Test that 'tagobject' collects all of an object's parameters and stores
# them in one TransObject, rather than many. This is probably a bad idea.